@@ -1,10 +1,10 @@
 #define QT_FEATURE_ffmpeg 1
 
-#define QT_FEATURE_pipewire 1
+#define QT_FEATURE_pipewire -1
 
-#define QT_FEATURE_pipewire_screencapture 1
+#define QT_FEATURE_pipewire_screencapture -1
 
-#define QT_FEATURE_alsa -1
+#define QT_FEATURE_alsa 1
 
 #define QT_FEATURE_avfoundation -1
 
@@ -26,7 +26,7 @@
 
 #define QT_FEATURE_gpu_vivante -1
 
-#define QT_FEATURE_linux_v4l 1
+#define QT_FEATURE_linux_v4l -1
 
 #define QT_FEATURE_linux_dmabuf 1
 
@@ -36,7 +36,7 @@
 
 #define QT_FEATURE_native_android_backend -1
 
-#define QT_FEATURE_pulseaudio 1
+#define QT_FEATURE_pulseaudio -1
 
 #define QT_FEATURE_opensles -1
 
